@@ -41,6 +41,7 @@ import (
 	"github.com/twpayne/go-shell"
 	"github.com/twpayne/go-vfs/v4"
 	"github.com/twpayne/go-xdg/v6"
+	cobracompletefig "github.com/withfig/autocomplete-tools/integrations/cobra"
 	"go.uber.org/multierr"
 	"golang.org/x/term"
 	"mvdan.cc/sh/v3/expand"
@@ -435,13 +436,14 @@ func newConfig(options ...configOption) (*Config, error) {
 		"gopass":                   c.gopassTemplateFunc,
 		"gopassRaw":                c.gopassRawTemplateFunc,
 		"include":                  c.includeTemplateFunc,
+		"includeTemplate":          c.includeTemplateTemplateFunc,
 		"ioreg":                    c.ioregTemplateFunc,
 		"joinPath":                 c.joinPathTemplateFunc,
 		"keepassxc":                c.keepassxcTemplateFunc,
 		"keepassxcAttachment":      c.keepassxcAttachmentTemplateFunc,
 		"keepassxcAttribute":       c.keepassxcAttributeTemplateFunc,
-		"keeper":                   c.keeperTemplateFunction,
-		"keeperDataFields":         c.keeperDataFieldsTemplateFunction,
+		"keeper":                   c.keeperTemplateFunc,
+		"keeperDataFields":         c.keeperDataFieldsTemplateFunc,
 		"keeperFindPassword":       c.keeperFindPasswordTemplateFunc,
 		"keyring":                  c.keyringTemplateFunc,
 		"lastpass":                 c.lastpassTemplateFunc,
@@ -1453,6 +1455,7 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 		c.newUpdateCmd(),
 		c.newUpgradeCmd(),
 		c.newVerifyCmd(),
+		cobracompletefig.CreateCompletionSpecCommand(),
 	} {
 		if cmd != nil {
 			rootCmd.AddCommand(cmd)
@@ -1694,14 +1697,14 @@ func (c *Config) persistentPreRunRootE(cmd *cobra.Command, args []string) error
 		if err != nil {
 			return err
 		}
-		dryRunPeristentState := chezmoi.NewMockPersistentState()
-		if err := persistentState.CopyTo(dryRunPeristentState); err != nil {
+		dryRunPersistentState := chezmoi.NewMockPersistentState()
+		if err := persistentState.CopyTo(dryRunPersistentState); err != nil {
 			return err
 		}
 		if err := persistentState.Close(); err != nil {
 			return err
 		}
-		c.persistentState = dryRunPeristentState
+		c.persistentState = dryRunPersistentState
 	case cmd.Annotations[persistentStateMode] == persistentStateModeReadWrite:
 		persistentStateFileAbsPath, err := c.persistentStateFile()
 		if err != nil {
@@ -2170,7 +2173,7 @@ func (c *Config) useBuiltinAgeAutoFunc() bool {
 	return true
 }
 
-// useBuiltinGitAutoFunc detects whether the builitin git should be used.
+// useBuiltinGitAutoFunc detects whether the builtin git should be used.
 func (c *Config) useBuiltinGitAutoFunc() bool {
 	// useBuiltinGit is false by default on Solaris as it uses the unavailable
 	// flock function.
