@@ -17,7 +17,7 @@ type managedCmdConfig struct {
 
 func (c *Config) newManagedCmd() *cobra.Command {
 	managedCmd := &cobra.Command{
-		Use:     "managed [paths]...",
+		Use:     "managed [path]...",
 		Aliases: []string{"list"},
 		Short:   "List the managed entries in the destination directory",
 		Long:    mustLongHelp("managed"),
@@ -36,18 +36,16 @@ func (c *Config) newManagedCmd() *cobra.Command {
 func (c *Config) runManagedCmd(cmd *cobra.Command, args []string, sourceState *chezmoi.SourceState) error {
 	include := c.managed.include.Sub(c.managed.exclude)
 
-	// Build queued paths. When no arguments, start from root; otherwise start
-	// from arguments.
-	paths := []chezmoi.RelPath{}
-	if len(args) != 0 {
-		for _, arg := range args {
-			if p, err := chezmoi.NormalizePath(arg); err != nil {
-				return err
-			} else if p, err := p.TrimDirPrefix(c.DestDirAbsPath); err != nil {
-				return err
-			} else {
-				paths = append(paths, p)
-			}
+	// Build queued relPaths. When there are no arguments, start from root,
+	// otherwise start from arguments.
+	var relPaths chezmoi.RelPaths
+	for _, arg := range args {
+		if absPath, err := chezmoi.NormalizePath(arg); err != nil {
+			return err
+		} else if relPath, err := absPath.TrimDirPrefix(c.DestDirAbsPath); err != nil {
+			return err
+		} else {
+			relPaths = append(relPaths, relPath)
 		}
 	}
 
@@ -61,10 +59,10 @@ func (c *Config) runManagedCmd(cmd *cobra.Command, args []string, sourceState *c
 			return nil
 		}
 
-		// when specified arguments, only include paths under these arguments
-		if len(paths) != 0 {
+		// When arguments are given, only include paths under these arguments.
+		if len(relPaths) != 0 {
 			included := false
-			for _, path := range paths {
+			for _, path := range relPaths {
 				if targetRelPath.HasDirPrefix(path) || targetRelPath.String() == path.String() {
 					included = true
 					break
