@@ -12,6 +12,7 @@ import (
 	"runtime"
 	"strconv"
 	"strings"
+	"text/template"
 
 	"github.com/bmatcuk/doublestar/v4"
 	"github.com/bradenhilton/mozillainstallhash"
@@ -29,7 +30,12 @@ type ioregData struct {
 	value map[string]any
 }
 
-var startOfLineRx = regexp.MustCompile(`(?m)^`)
+var (
+	// needsQuoteRx matches any string that contains non-printable characters,
+	// double quotes, or a backslash.
+	needsQuoteRx  = regexp.MustCompile(`[^\x21\x23-\x5b\x5d-\x7e]`)
+	startOfLineRx = regexp.MustCompile(`(?m)^`)
+)
 
 func (c *Config) commentTemplateFunc(prefix, s string) string {
 	return startOfLineRx.ReplaceAllString(s, prefix)
@@ -87,23 +93,41 @@ func (c *Config) globTemplateFunc(pattern string) []string {
 }
 
 func (c *Config) includeTemplateFunc(filename string) string {
-	var absPath chezmoi.AbsPath
-	if filepath.IsAbs(filename) {
-		var err error
-		absPath, err = chezmoi.NewAbsPathFromExtPath(filename, c.homeDirAbsPath)
-		if err != nil {
-			panic(err)
-		}
-	} else {
-		absPath = c.SourceDirAbsPath.JoinString(filename)
-	}
-	contents, err := c.fileSystem.ReadFile(absPath.String())
+	contents, err := c.readFile(filename)
 	if err != nil {
 		panic(err)
 	}
 	return string(contents)
 }
 
+func (c *Config) includeTemplateTemplateFunc(filename string, args ...any) string {
+	var data any
+	switch len(args) {
+	case 0:
+		// Do nothing.
+	case 1:
+		data = args[0]
+	default:
+		panic(fmt.Errorf("expected 0 or 1 arguments, got %d", len(args)))
+	}
+
+	contents, err := c.readFile(filename)
+	if err != nil {
+		panic(err)
+	}
+
+	tmpl, err := template.New(filename).Funcs(c.templateFuncs).Parse(string(contents))
+	if err != nil {
+		panic(err)
+	}
+
+	var builder strings.Builder
+	if err := tmpl.Execute(&builder, data); err != nil {
+		panic(err)
+	}
+	return builder.String()
+}
+
 func (c *Config) ioregTemplateFunc() map[string]any {
 	if runtime.GOOS != "darwin" {
 		return nil
@@ -188,6 +212,20 @@ func (c *Config) quoteListTemplateFunc(list []any) []string {
 	return result
 }
 
+func (c *Config) readFile(filename string) ([]byte, error) {
+	var absPath chezmoi.AbsPath
+	if filepath.IsAbs(filename) {
+		var err error
+		absPath, err = chezmoi.NewAbsPathFromExtPath(filename, c.homeDirAbsPath)
+		if err != nil {
+			return nil, err
+		}
+	} else {
+		absPath = c.SourceDirAbsPath.JoinString(filename)
+	}
+	return c.fileSystem.ReadFile(absPath.String())
+}
+
 func (c *Config) replaceAllRegexTemplateFunc(expr, repl, s string) string {
 	return regexp.MustCompile(expr).ReplaceAllString(s, repl)
 }
@@ -275,7 +313,11 @@ func writeIniMap(w io.Writer, data map[string]any, sectionPrefix string) error {
 			}
 			subsections = append(subsections, subsection)
 		case string:
-			fmt.Fprintf(w, "%s = %q\n", key, value)
+			if needsQuote(value) {
+				fmt.Fprintf(w, "%s = %q\n", key, value)
+			} else {
+				fmt.Fprintf(w, "%s = %s\n", key, value)
+			}
 		default:
 			return fmt.Errorf("%s%s: %T: unsupported type", sectionPrefix, key, value)
 		}
@@ -294,6 +336,22 @@ func writeIniMap(w io.Writer, data map[string]any, sectionPrefix string) error {
 	return nil
 }
 
+func needsQuote(s string) bool {
+	if s == "" {
+		return true
+	}
+	if needsQuoteRx.MatchString(s) {
+		return true
+	}
+	if _, err := strconv.ParseBool(s); err == nil {
+		return true
+	}
+	if _, err := strconv.ParseFloat(s, 64); err == nil {
+		return true
+	}
+	return false
+}
+
 func sortedKeys[K constraints.Ordered, V any](m map[K]V) []K {
 	keys := maps.Keys(m)
 	slices.Sort(keys)
